;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "notmuch" "20250620.1557"
  "Run notmuch within emacs."
  ()
  :url "https://notmuchmail.org"
  :commit "63665f1ebd6eff7753b7798add657fd6dbd110d6"
  :revdesc "63665f1ebd6e")
